![](devs.png)
# shitcoin
## How, devs?
[Welcome to web3, anon, YOU ARE SO EARLY!1!1](https://medium.com/osmosis/introducing-osmosis-frontier-d9da158b22d0)

As you race to make the [`$TOKEN`](https://mobile.twitter.com/alpeh_v/status/1479220092336496648) for your community of value liquid on [Osmosis Frontier](https://frontier.osmosis.zone/), [JunoSwap](https://junoswap.com/), or anywhere `cw20` are sold, you may wonder how to get the `denom` value for your world-changing IBC asset.

How does `$RAC` become `ibc/6BDB4C8CCD45033F9604E4B93ED395008A753E01EECD6992E7D1EA23D9D3B788` in [osmosis-frontier.assetlist.json](https://github.com/osmosis-labs/assetlists/blob/3f31ff89eb910fe4efe1de074e74a6bcd32e57a3/osmosis-1/osmosis-frontier.assetlist.json#L1381)?

Wonder no more, `shitcoin` is here help!
## Usage
### Install
```
pip3 install shitcoin
```
### Create your DAO
To create your `cw20` without becoming a CosmWasm expert, get yourself some `$JUNO` and head over to [DAO DAO](https://daodao.zone/dao/juno18z6rxlnmw0f86maxuzv0z6mwtxrflam8xjpsqacy6y5m5eu34y7qjqegk2) where you can go from 0 to DeFi hero without code, and for `< 0.5 $USD`.

Once you [create your DAO](https://daodao.zone/dao/create), take note of its `cw20 token` address.

For example, [this DAO](https://daodao.zone/dao/juno18z6rxlnmw0f86maxuzv0z6mwtxrflam8xjpsqacy6y5m5eu34y7qjqegk2) has its at:

`juno14cr367h7vrgkx4u6q6prk2s29rlrp8hn478q2r9zrpyhkx7mx5dsuw7syw`
### ???
```
dude@starlanes % python3 
Python 3.9.12 (main, Mar 26 2022, 15:44:31) 
[Clang 13.1.6 (clang-1316.0.21.2)] on darwin
Type "help", "copyright", "credits" or "license" for more information.
>>> from shitcoin import cw20_ibc_denom
>>> cw20_ibc_denom("transfer", "channel-169", "cw20:juno14cr367h7vrgkx4u6q6prk2s29rlrp8hn478q2r9zrpyhkx7mx5dsuw7syw")
'ibc/8C8BFD62EA45671ADEBA13835AF3DEAAA0661EA7D1283BB1C54D679898DB29FB'
```

Follow the steps from your [permissionless DEX / AMM of choice](https://docs.osmosis.zone/integrate/frontend.html#how-to-add-an-asset-onto-the-osmosis-assets-page) to list the asset and use the denomination value obtained `ibc/...` with quiet confidence. At this poin you can drop your new `$TOKEN` to your frens and aligned fellow travelers as you celebrate the launch by [finding something fun to watch on C-SPAN](https://www.c-span.org/video/?516464-1/house-hearing-financial-innovation-digital-currency), describe what you are up to and encourage them to ape in.

If stuck, help yourself to some copy-pasta w/ existing `cw20` and submit all the necessary PRs after thoughtfully adjusting [theirs](https://github.com/osmosis-labs/osmosis-frontend/pulls?q=is%3Apr+is%3Aclosed+RAC).
### Profit!1!
Swap tokens with aligned DAOs / chains, create LPs to allow for the unencumbered flow of value between you and incentivize participation by dispensing rewards at each epoch.

For extra street cred, write about your deflationary tokenomics publicly and _stick to it_.

After some time, convert a _small_ portion of the value of your network into stables with exits to fiat for hot cocoa and naps, thereby monetizing your community without resorting to predatory surveillance capitalism.

## Support
The team behind `shitcoin` is default-alive.

However, it would please us if you start your own DAO as long as you...

- [do not pull rugs](https://www.youtube.com/watch?v=gCFlGLbI_kE)
- [learn the fundamentals](https://www.youtube.com/playlist?list=PLEGCF-WLh2RLOHv_xUGLqRts_9JxrckiA)
- discover a missing market with shitty Nash equilibria and use your sovereign programmable money to [nudge the participants to play a better game 🕹](https://medium.com/@virgilgr/ethereum-is-game-changing-technology-literally-d67e01a01cf8)
- above all, have fun and always remember that not everything needs to be commodified!

If you insist on sharing the spoils, direct your donations to [Topos Institute](https://crm.bloomerang.co/HostedDonation?ApiKey=pub_ea742ae0-60bf-11eb-ad37-023f69b29baf&WidgetId=18432) who work tirelessly to help us all solve [actually hard problems](https://www.youtube.com/watch?v=894CGgiiEKU). 

Also, check out [Anoma](https://anoma.net/vision-paper.pdf) if you are disgusted by Ponzinomics but are still interested in governance innovation.